#!/bin/csh -f
#PBS -e en_cons.err
#PBS -o en_cons.log
#PBS -l nodes=1:ppn=3
#PBS -l walltime=1:00:00
#PBS -m ae
# Job name:
#PBS -N test_en_cons_T
#PBS -r n


# if running as PBS job, change into the correct directory (the directory containing this file)
if ($?PBS_O_WORKDIR) then
cd $PBS_O_WORKDIR
endif

set pb = 16
set tp = 8
set num_blocks = 10
@ block_factor = 100

printf "Physics test: energy conservation - vary termperature.\n"

set dt_list = (0.0001 0.0002 0.0004 0.0008 0.0016 0.0032 0.0064)
set w_interval_list = (64 32 16 8 4 2 1)


foreach i (1 2 3 4 5 6 7)
set dt = $dt_list[$i]
@ w_interval = $w_interval_list[$i]
@ block_size =  $w_interval * $block_factor



(../../../../UserPrograms/md_pair  --numIOBlocks=${num_blocks} --IOBlockSize=${block_size} --pb=$pb --tp=$tp --dt=${dt} --thermostat=0 --device=0 --dump_nrg=${w_interval} --writeTraj=0 --write_v_com_x=1 --mom_reset=0 --out_prec=9 > en_cons${dt}.log) >& en_cons${dt}.err
zcat TrajectoryFiles/energies*.dat.gz > energies${dt}.dat

rm -rf TrajectoryFiles
end

grep "Processing time GPU" en_cons*.log > cpu_times.log
echo "To plot the energies, do: xmgrace -block energies0.0001.dat -bxy 0:6 -block energies0.0002.dat -bxy 0:6 -block energies0.0004.dat -bxy 0:6 -block energies0.0008.dat -bxy 0:6 -block energies0.0016.dat -bxy 0:6 -block energies0.0032.dat -bxy 0:6 -block energies0.0064.dat -bxy 0:6"

echo "To calculate energy fluctuations and drift, do: python ../Analysis.py [results will be in stdE_vs_dt.dat]"


