#include "rumd_stats.h"
#include "rumd/RUMD_Error.h"
#include <iostream>
#include <cstdio>
#include <cstdlib>

int main(int argc, char *argv[])
{  
  bool verbose = false;
  std::string directory("TrajectoryFiles");
  unsigned int first_block = 0;
  int last_block = -1;

  static const char *usage = "Usage: %s [-h] [-f<first_block>] [-l<last_block>] [-v=<verbose> ] [-d=directory]\n";
  int opt;
  while ((opt = getopt(argc, argv, "hf:l:v:d:")) != -1) {
    switch (opt) {
    case 'h':
      fprintf(stdout, usage, argv[0]);
      exit(EXIT_SUCCESS);
    case 'f':
      first_block = atoi(optarg);
      break;
    case 'l':
      last_block = atoi(optarg);
      break;
    case 'v':
      verbose = (bool) atoi(optarg);
      break;
    case 'd':
      directory = std::string(optarg);
      break;
    case '?':
      fprintf(stderr, "%s: unknown option: -%c\n", argv[0], optopt);
      fprintf(stderr, usage, argv[0]);
      exit(EXIT_FAILURE);
      break;
    case ':':
      fprintf(stderr, "%s: missing option argument for option: -%c\n", argv[0], optopt);
      fprintf(stderr, usage, argv[0]);
      exit(EXIT_FAILURE);
      break;
    default:
      fprintf(stderr, usage, argv[0]);
      exit(EXIT_FAILURE);
    }
  }
  
  try {
    rumd_stats rs;
    rs.SetVerbose(verbose);
    rs.SetDirectory(directory);
    rs.ComputeStats(first_block, last_block);
    rs.PrintStats();
    rs.WriteStats();
  }
  catch(RUMD_Error e){
    std::cerr << "RUMD_Error thrown from function " << e.className << "::" << e.methodName << ": " << std::endl << e.errorStr << std::endl;
    return 1;
  }
  return 0;
}
